==> skill-core-23.0.1-sources.jar: com/ptteng/common/skill/service/MessageService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.Message;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface MessageService extends BaseDaoService {


    public Long insert(Message message) throws ServiceException, ServiceDaoException;


    public List<Message> insertList(List<Message> messageList) throws ServiceException, ServiceDaoException;


    public boolean delete(Long id) throws ServiceException, ServiceDaoException;


    public boolean update(Message message) throws ServiceException, ServiceDaoException;

    public boolean updateList(List<Message> messageList) throws ServiceException, ServiceDaoException;


    public Message getObjectById(Long id) throws ServiceException, ServiceDaoException;


    public List<Message> getObjectsByIds(List<Long> ids) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countMessageIdsBySendIdAndStatus(Long sendId, Integer status) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countMessageIdsByReceiveIdAndStatus(Long receiveId, Integer status) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsBySendIdAndStatus(Long sendId, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatus(Long receiveId, Integer unread, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatusAndType(Long receiveId, Integer unread, Integer status, String type, Integer start, Integer limit) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndStatus(Long receiveId, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException;

    public List<Long> getMessageIdsByReceiveIdAndStatusAndType(Long receiveId, Integer status, String type,Integer start, Integer limit) throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countMessageIds() throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsBySendIdAndStatusAndType(Long uid ,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndStatusAndTypePrivate(Long uid ,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndSendId(Long uid ,Long pid,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessagesTodayUnixList(Long uid ,Long minTodayUnix,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;


    public Integer countMessagesBySendIdAndReceiveId(Long sendId, Long receiveId )
            throws ServiceException, ServiceDaoException;





}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/service/MessageService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.Message;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface MessageService extends BaseDaoService {


    public Long insert(Message message) throws ServiceException, ServiceDaoException;


    public List<Message> insertList(List<Message> messageList) throws ServiceException, ServiceDaoException;


    public boolean delete(Long id) throws ServiceException, ServiceDaoException;


    public boolean update(Message message) throws ServiceException, ServiceDaoException;

    public boolean updateList(List<Message> messageList) throws ServiceException, ServiceDaoException;


    public Message getObjectById(Long id) throws ServiceException, ServiceDaoException;


    public List<Message> getObjectsByIds(List<Long> ids) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countMessageIdsBySendIdAndStatus(Long sendId, Integer status) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countMessageIdsByReceiveIdAndStatus(Long receiveId, Integer status) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsBySendIdAndStatus(Long sendId, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatus(Long receiveId, Integer unread, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatusAndType(Long receiveId, Integer unread, Integer status, String type, Integer start, Integer limit) throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndStatus(Long receiveId, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException;

    public List<Long> getMessageIdsByReceiveIdAndStatusAndType(Long receiveId, Integer status, String type,Integer start, Integer limit) throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public Integer countMessageIds() throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsBySendIdAndStatusAndType(Long uid ,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndStatusAndTypePrivate(Long uid ,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;

    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessageIdsByReceiveIdAndSendId(Long uid ,Long pid,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;


    /**
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    public List<Long> getMessagesTodayUnixList(Long uid ,Long minTodayUnix,Integer start, Integer limit)
            throws ServiceException, ServiceDaoException;


    public Integer countMessagesBySendIdAndReceiveId(Long sendId, Long receiveId )
            throws ServiceException, ServiceDaoException;

//    public List<Long> getMessageIdsByTemplate(Long uid ,Integer Template,Integer start, Integer limit)
//            throws ServiceException, ServiceDaoException;



}
